/*
 * Title: wire.h
 * Author: Jed Marti KI7NNP
 * Description: Wire constants. The enamel measurements taken from actual measurements, the other
 *   values from differeent on-line sources.
 * Revision History: (Created Sun Mar 12 08:36:58 2023)
 *   Thu Jan 25 08:36:10 2024 - Review for release.
 */


#ifndef wire_h
#define wire_h

typedef struct {
  char    *name;         // Gauge name.
  double  bare;          // Bare diameter (inches).
  double  enamel;        // Enamel diameter (inches, -1.0 if not known).
  double  ohms;          // Ohms/1000'
  double  maxA;          // Maximum amps for chassis wiring.
  double  weight;        // Weight  lbs/1000'
  int32_t gauge;         // Wire gauge.
} WireData_t;


#define WireTable          \
WireData_t W[] = {         \
  {.name="#32",            \
   .gauge=32,              \
   .bare=0.008,            \
   .enamel=-1.0,           \
   .weight=.194,           \
   .ohms=166,              \
   .maxA=0.53},            \
  {.name="#30",            \
   .gauge=30,              \
   .bare=0.010,            \
   .enamel=-1.0,           \
   .weight=0.303,          \
   .ohms=106,              \
   .maxA=0.86},            \
  {.name="#28",            \
   .gauge=28,              \
   .bare=0.0126,           \
   .enamel=0.0145,         \
   .weight=0.481,          \
   .ohms=66.4,             \
   .maxA=1.4},             \
  {.name="#26",            \
   .gauge=26,              \
   .bare=0.0159,           \
   .enamel=0.017,          \
   .weight=0.765,          \
   .ohms=42.1,             \
   .maxA=2.2},             \
  {.name="#24",            \
   .gauge=24,              \
   .bare=0.0201,           \
   .enamel=0.02125,        \
   .weight=1.22,           \
   .ohms=26.2,             \
   .maxA=3.5},             \
  {.name="#22",            \
   .gauge=22,              \
   .bare=0.0253,           \
   .enamel=0.027,          \
   .weight=1.94,           \
   .ohms=16.6,             \
   .maxA=7.0},             \
  {.name="#20",            \
   .gauge=20,              \
   .bare=0.0320,           \
   .enamel=-1.0,           \
   .weight=3.10,           \
   .ohms=10.3,             \
   .maxA=9.0},             \
  {.name="#18",            \
   .gauge=18,              \
   .bare=0.0403,           \
   .enamel=0.0430,         \
   .weight=4.92,           \
   .ohms=6.51,             \
   .maxA=16.0},            \
  {.name="#16",            \
   .gauge=16,              \
   .bare=0.0508,           \
   .enamel=0.054,          \
   .weight=7.81,           \
   .ohms=4.1,              \
   .maxA=22.0},            \
  {.name="#14",            \
   .gauge=14,              \
   .bare=0.0641,           \
   .enamel=0.067,          \
   .weight=10.9,           \
   .ohms=3.51,             \
   .maxA=32.0}             \
}


#endif


// EOF
